==> haskell-wai-logger-2.2.4.1-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.2.4.1
id: wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
key: wailo_LehKhwfMAzKAYIng6nj4Ez
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.Date
                Network.Wai.Logger.IP Network.Wai.Logger.IORef
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
hs-libraries: HSwai-logger-2.2.4.1-LehKhwfMAzKAYIng6nj4Ez
depends:
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    byteorder-1.0.4-d0724ebba5f7969f1b97a3570748951d
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.2.4.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-logger/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.2.4.1
id: wai-logger-2.2.4.1-b4d6891e20083c91ee31e279044b2010
key: wailo_5SmWuEinP5Z6qUjoTvkeI6
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.Date
                Network.Wai.Logger.IP Network.Wai.Logger.IORef
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-logger-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-logger-2.2.4.1
hs-libraries: HSwai-logger-2.2.4.1-5SmWuEinP5Z6qUjoTvkeI6
depends:
    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    byteorder-1.0.4-d0724ebba5f7969f1b97a3570748951d
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    easy-file-0.2.1-9b22ae8f4cbee2da82c99a0d82e5050c
    fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-time-0.3.6-139be0d28d6f361941053e7ff9473819
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
